#
# spec file for package system-config-printer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _icontheme adwaita
%define _iconlocation Adwaita
Name:           system-config-printer
Version:        1.5.18
Release:        9.2
Summary:        A printer administration tool
License:        GPL-2.0-or-later
Group:          Hardware/Printing
URL:            https://github.com/OpenPrinting/system-config-printer/
Source0:        https://github.com/OpenPrinting/system-config-printer/releases/download/v%{version}/system-config-printer-%{version}.tar.gz
Source1:        https://github.com/OpenPrinting/system-config-printer/releases/download/v%{version}/system-config-printer-%{version}.tar.gz.asc
Source98:       system-config-printer.keyring
Source99:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE system-config-printer-icon-brp-friendly.patch vuntz@novell.com -- brp checks don't like the printer icon name, so we have to use something else
Patch13:        system-config-printer-icon-brp-friendly.patch
# PATCH-FIX-OPENSUSE system-config-printer-no-openprinting.patch bnc#733542 vuntz@opensuse.org -- Disable feature that downloads ppd from openprinting.org
Patch19:        system-config-printer-no-openprinting.patch
# PATCH-FIX-UPSTREAM installation-root-dir-from-setup.patch -- gh#OpenPrinting/system-config-printer#361
Patch20:        installation-root-dir-from-setup.patch
# PATCH-FEATURE-OPENSUSE system-config-printer-no-simple-gui.patch boo#1090189 dimstar@opensuse.org -- Remove unused _simple_gui class in openprinting.py. Pulls in GTK
Patch100:       system-config-printer-no-simple-gui.patch
# For directory ownership
BuildRequires:  %{_icontheme}-icon-theme
BuildRequires:  cups-devel
BuildRequires:  dbus-1
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  glib2-devel
# Needed for typelib() requires
BuildRequires:  gobject-introspection
# For directory ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-lxml
BuildRequires:  python3-setuptools
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libudev) >= 172
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires:       %{name}-common = %{version}
Requires:       python3-cups
Requires:       python3-pycurl
# The applet is not strictly necessary, but it really makes sense
Recommends:     %{name}-applet
Obsoletes:      gnome-cups-manager <= 0.33

%description
system-config-printer is a graphical user interface that allows the
user to configure a CUPS print server.

%package common
Summary:        Common files for GNOME's printer administration tool
Group:          Hardware/Printing
Requires:       dbus-1-python3
Requires:       python3-cairo
Requires:       python3-cups >= 1.9.60
Requires:       python3-cupshelpers
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-smbc
Recommends:     cups-pk-helper
# As soon as this package is installed, it makes sense to have the
# autoconfiguration too
Recommends:     udev-configure-printer
BuildArch:      noarch

%description common
system-config-printer is a graphical user interface that allows the
user to configure a CUPS print server.

This package provides files common to various binaries.

%package applet
Summary:        Notification icon for printing via system-config-printer
Group:          Hardware/Printing
Requires:       %{name} = %{version}
# Uses the dbus service to interact with print jobs
Requires:       %{name}-dbus-service = %{version}
Provides:       dbus(com.redhat.NewPrinterNotification)
BuildArch:      noarch

%description applet
system-config-printer is a graphical user interface that allows the
user to configure a CUPS print server.

This package provides a notification icon to configure new printers and
monitor print jobs.

%package dbus-service
Summary:        D-Bus service to configure printing via system-config-printer
Group:          Hardware/Printing
Requires:       %{name}-common = %{version}
BuildArch:      noarch

%description dbus-service
system-config-printer is a graphical user interface that allows the
user to configure a CUPS print server.

This packages provides a D-Bus service to configure printers and manage
print jobs.

%package -n python3-cupshelpers
Summary:        High-level Python Bindings for CUPS
Group:          Hardware/Printing
Requires:       python3-cups >= 1.9.60
Requires:       python3-pycurl
Requires:       python3-requests
BuildArch:      noarch

%description -n python3-cupshelpers
This package provides high-level python bindings for CUPS, and can be
used on top of python3-cups.

%package -n udev-configure-printer
Summary:        Utility to autoconfigure printers when plugged
Group:          Hardware/Printing
Requires:       dbus-1-python3
Requires:       python3-cups >= 1.9.60
Requires:       python3-cupshelpers
# do not make this recommended! it would pull in KDE or GNOME
# applets, even if udev-configure-printer is used on servers
Suggests:       dbus(com.redhat.NewPrinterNotification)
Obsoletes:      cups-autoconfig <= 0.1.0
%systemd_requires

%description -n udev-configure-printer
This package contains an utility that will ensure printers get
automatically configured when plugged on the computer.

%lang_package -n system-config-printer-common

%prep
%autosetup -p1

%build
if pkg-config --exists "cups"; then
%configure \
        --with-udev-rules \
        --with-systemdsystemunitdir=%{_unitdir}
else
%configure \
        --with-cups-serverbin-dir='/usr/lib/cups/' \
        --with-udev-rules \
        --with-systemdsystemunitdir=%{_unitdir}
fi

%install
%make_install dbusdir=%{_datadir}/dbus-1/system.d/

mkdir -p %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps
cp -a %{_datadir}/icons/%{_iconlocation}/scalable/devices/printer.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%fdupes %{buildroot}/%{py_sitedir}
%find_lang %{name} %{?no_lang_C}
%if 0%{?suse_version} >= 1600
%python3_fix_shebang_path %{buildroot}%{_prefix}/lib/udev/udev-add-printer
%python3_fix_shebang_path %{buildroot}%{_datadir}/system-config-printer/*
%python3_fix_shebang_path %{buildroot}%{_datadir}/system-config-printer/troubleshoot/*
%endif

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/%{name}
%{_bindir}/install-printerdriver
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/system-config-printer.appdata.xml
%{_datadir}/applications/system-config-printer.desktop
%{_mandir}/man1/system-config-printer.1%{?ext_man}

%files common
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/scalable/apps/system-config-printer.svg

%files applet
%{_bindir}/%{name}-applet
%{_mandir}/man1/system-config-printer-applet.1%{?ext_man}
# The dbus service is provided by applet.py
%{_datadir}/dbus-1/system.d/com.redhat.NewPrinterNotification.conf
%{_sysconfdir}/xdg/autostart/print-applet.desktop

%files dbus-service
%{_bindir}/scp-dbus-service
%{_datadir}/dbus-1/interfaces/org.fedoraproject.Config.Printing.xml
%{_datadir}/dbus-1/services/org.fedoraproject.Config.Printing.service

%files -n python3-cupshelpers
%dir %{_sysconfdir}/cupshelpers
%config(noreplace) %{_sysconfdir}/cupshelpers/preferreddrivers.xml
%exclude %{python3_sitelib}/cupshelpers/__pycache__/*.pyc
%{python3_sitelib}/cupshelpers
%{python3_sitelib}/cupshelpers*.egg-info
# The dbus service is provided by cupshelpers/installdriver.py
%{_datadir}/dbus-1/system.d/com.redhat.PrinterDriversInstaller.conf

%files -n udev-configure-printer
%{_unitdir}/configure-printer@.service
%dir %{_prefix}/lib/udev
%dir %{_prefix}/lib/udev/rules.d
%{_prefix}/lib/udev/rules.d/*.rules
%{_prefix}/lib/udev/udev-add-printer
%{_prefix}/lib/udev/udev-configure-printer

%files common-lang -f %{name}.lang

%changelog
* Fri Nov 29 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add installation-root-dir-from-setup.patch
  gh#OpenPrinting/system-config-printer#361 to fix cupshelpers
  installation.
* Fri Nov 22 2024 Dirk Müller <dmueller@suse.com>
- add keyring for gpg validation
- add python3-setuptools dependency (needed for python 3.13)
* Wed Jul 17 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Drop obsolete update-desktop-files BuildRequires and macro.
* Fri Mar  8 2024 pgajdos@suse.com
- another %%python3_fix_shebang_path usage [bsc#1212476]
* Mon Feb 26 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Mon Nov 27 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup -p1 instead of multiple %%patch lines. Allows us to
  get rid of deprecated %%patchN.
* Wed Aug  2 2023 Yifan Jiang <yfjiang@suse.com>
- Explicitly use --with-cups-serverbin-dir to find SERVERBIN when
  cups.pc is not provided by older cups (boo#1213883).
* Mon Mar 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Fix printer icon location/type, needed due to changes in Adwaita.
* Mon Nov 14 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.5.18:
  + Add <launchable/>  into the .appdata.xml file.
  + Accessiblity improvements.
  + system-config-printer couldn't be uninstalled via GNOME
    Software.
  + system-config-printer crashes due missing libhandy.
  + Updated config.sub and config.guess to fix configuration error
    on RiSC.
  + Use pkg-config or --with-cups-serverbin-dir for finding
    SERVERBIN.
* Thu Aug 11 2022 Callum Farmer <gmbr3@opensuse.org>
- Move all dbus-1 system.d files to /usr (bsc#1202340)
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.5.16:
  + fix preserve_job_files default settings.
  + add debugprint covering failed fingerprint retrieval attempts.
  + Make sure that applet.py is running one instance per user.
  + fix incorrect use of urllib.request.
  + remove python3-requests.
  + build: Migrate build system from Intltool to Gettext.
  + udev-configure-printer.c: Fix possible use after frees and
    leaks.
  + scp-dbus-service.py: Fix typo in method call.
  + add option to disable xmlto manual generation.
  + allow + in device uris - gutenprint has a backend with +.
- Drop python3-requests requires: no longer needed, following
  upstream changes.
- Rebase system-config-printer-no-openprinting.patch.
* Mon Jan 10 2022 Yifan Jiang <yfjiang@suse.com>
- Add python-rpm-macros BuildRequires in case some build
  environment does not pull it automatically. This is needed by
  macros like %%{python3_sitelib}.
* Sat Dec  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Fix icons yet again, this time what sizes are available.
- Drop post(un) handling, this is done automatically now.
* Sun Apr 18 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.5.15 (boo#1184930):
  + set the minimum gettext version because autoconf 2.70 requires
    it.
  + create README file because autoconf requires it.
- Changes from version 1.5.14:
  + set preferred driver for DYMO LabelWriter 400.
  + udev: ignore devices capable of IPP over USB, we have ipp-usb
    for it.
  + asyncpk1.py: dont require the exact Gdk version.
- Changes from version 1.5.13:
  + add checks for NULL in udev-configure-printer.
  + github #174 - put back notification about missing pysmbc.
  + python3.9 - xml module removed elem.getchildren() method,
    use list(elem).
  + Make the matching rule of printer device path more flexible.
- For more details of the update between 1.5.7 and 1.5.13, please
  see packaged NEWS file.
- Drop upstream merged patches:
  + 0001-Fallback-to-using-LC_CTYPE-if-LC_MESSAGES-is-empty-a.patch
  + fix_connect_dialog_focus.diff
  + system-config-printer-no-params-to-py3.patch
  + system-config-printer-Gtk-introspect.patch
  + system-config-printer-no-applet-in-gnome.patch
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Sep  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Fix printer icon location again, needed due to changes in
  Adwaita. Now back to old location.
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Thu May 23 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Require python3-requests by python3-cupshelpers (boo#1116867).
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Fix printer icon location, needed due to changes in Adwaita.
* Thu May 31 2018 alarrosa@suse.com
- Add 0001-Fallback-to-using-LC_CTYPE-if-LC_MESSAGES-is-empty-a.patch.
  This fixes an error message when adding a new printer since the code
  was finding out the language by using LC_MESSAGES which wasn't set
  and then it was extracting the first element of a None value.
* Mon Apr 23 2018 dimstar@opensuse.org
- Add system-config-printer-no-simple-gui.patch: Remove _simple_gui
  class from openprinting.py: this class pulls in a GTK stack, but
  then is actually never used (boo#1090189).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 20 2018 lnussel@suse.de
- Do not recommend dbus(com.redhat.NewPrinterNotification) as this
  would pull in desktop applets also on a server installation
  (boo#1081691)
* Fri Sep 15 2017 jengelh@inai.de
- Replace some old RPM variables and macros by current constructs.
- Update package summaries.
* Thu Sep 14 2017 fezhang@suse.com
- Drop SLE12 conditionals, unconditionally use Adwaita icon theme
  and python3.
  + Drop python3-to-python2.diff.
* Wed Aug 16 2017 fvogt@suse.com
- Do not recommend the applet directly, but the dbus service
  to allow alternatives to get installed instead
* Tue Jun 14 2016 dimstar@opensuse.org
- Add Require python(3)?-gobject-Gdk: pygobject was further split
  in order to be able to install it without X-dependencies. We
  import Gdk from gi.repository, thus also require
  python-gobject-Gdk (boo#984252).
* Tue Jun  7 2016 alarrosa@suse.com
- Modified python3-to-python2.diff : One of the changes included
  there now comes in fix_connect_dialog_focus.diff.
- Create a python3-cupshelpers or python-cupshelpers package
  depending on the value of the use_python3 variable.
- Require python3-cups or python-cups (and the associated
  python3-cupshelpers/python-cupshelpers) depending on the case.
- Remove %%py_requires: It's not really needed.
- Merge the spec file from SLE12-SP2 and GNOME:Factory
  (bnc#983255).
* Fri Jun  3 2016 dimstar@opensuse.org
- Do not handle template service (configure-printer@) with the
  sytemd service_* macros (boo#982299).
- Add rpmlintrc to silence the warnings about it.
* Fri May  6 2016 alarrosa@suse.com
- Add fix_connect_dialog_focus.diff: Enable the focus on the text
  entry part of the combobox in the Connect Dialog. This way, users
  can edit its content and write the ip of the remote cups server
  to connect to (gh#twaugh/system-config-printer#38).
* Fri Apr 22 2016 alarrosa@suse.com
- Add python3-to-python2.diff : Remove all python3 dependencies.
- Modified python3 dependencies in the spec file too to use python2
  in SLE12.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Nov 17 2015 dimstar@opensuse.org
- Move system-config-printer to the main package where also the
  respective .desktop file is packaged.
* Mon Aug 31 2015 dimstar@opensuse.org
- Add system-config-printer-no-params-to-py3.patch: Do not launch
  udev-add-printer with invalid parameters (boo#942809).
* Thu Aug  6 2015 dimstar@opensuse.org
- Explicitly BuildRequire pkgconfig(udev): its existence is
  verified in configure.
* Mon Jun 22 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata for openSUSE:42.
* Fri May 15 2015 dimstar@opensuse.org
- Update to version 1.5.7:
  + Test device ordering: hp beats dnssd and usb.
  + Fixes for appdata file.
  + Fixed traceback (lp#1213136).
  + Set use_underline=True for previously-stock buttons
    (lp#1210859).
  + Increase bus settle time for usb_modeswitch devices
    (lp#1206808).
* Thu Mar 19 2015 zaitor@opensuse.org
- Update to version 1.5.6:
  + Don't show traceback messages for missing probe helpers
    (lp#1194101).
  + Don't try writing bytecache when running udev-add-printer
    (lp#1196183).
  + Don't try decoding already-decoded Unicode (lp#1195974).
  + Fixes for CMD matching (lp#1177978, lp#1171874).
  + Fixed 'Apply' sensitivity when downloading driver.
  + Avoid deprecated things.
  + Handle missing 'functionality' field in returned data for
    driver.
  + Some fixes for the New Printer dialog.
  + Don't install an OpenPrinting driver if the license is not
    accepted.
* Thu Mar 12 2015 dimstar@opensuse.org
- Update to version 1.5.5:
  + Bugs fixed: lp#1176443, lp#1186475, lp#1181043, lp#1179590,
    lp#1171469, lp#1397750, lp#1167978, lp#1167978, lp#1167978.
  + Updated translations.
- Add keyring and .sig file for gpg validation.
* Thu Mar 12 2015 dimstar@opensuse.org
- Fix system-config-printer-no-openprinting.patch: an indent of one
  block was lost in the last rebase.
- Require python3-cups instead of cups directly: we require the
  bindings and never speak to cups directly (boo#922000).
- Add python3-pycurl and python3-requests Requires: needed
  dependencies to start.
* Tue Jan 20 2015 sfalken@opensuse.org
- Update to version 1.5.4:
  + Updated aclocal.m4.
  + Included an AppData file.
  + Never set SMB Verify button sensitive without checking
    pysmb is available.
  + newprinter: fixed lock handling when OpenPrintingRequest
    is cancelled.
  + newprinter: Don't make installpackage errors completely
    silent.
  + PhysicalDevice: extract hostname from hp:/net/...?hostname=
    URIs (rh#1154686).
  + newprinter.py: If additional utilities are needed, do not
    try to install them twice.
  + Make recognition of HP MFPs with scan functionality actually
    work, instead of considering everything as HP scanner.
  + Check for both /etc/sane.d/dll.d/hpaio and
    /etc/sane.d/dll.d/hplip so that it works with both Red Hat
    and Ubuntu.
  + newprinter.py: Import installpackage so that PackageKit-based
    package installation actually works.
  + installpackage.py: Use D-Bus directly to communicate with
    PackageKit.
  + ppdcache: return exception rather than looping.
  + Removed empty translations.
  + timedops: Don't try to remove sources that are already removed.
  + Tell user how to retrieve journal entries as root (rh#1157253).
  + Fixed parsing of HPLIP fax type, as implicit conversion from
    string to int does not work anymore (lp#1369789).
  + Don't treat CUPS IPP conformance failure state reasons as
    errors.
  + Codec fix for AuthDialog.get_auth_info (rh#1060453).
  + Fix path for screenshots.
  + Added AppData screenshots.
  + Fixed physical device identification.
  + The cupshelpers.ppds.normalize() function is used first now.
  + jobviewer: alweys fetch auth-info-required attribute
    (lp#1380514).
  + Don't try installing smb backend a second time.
  + Show New Printer dialog immediately for printer_with_uri mode
    (rh#1158743).
  + monitor: another update timer handling issue.
  + Cancel deferred timer on quit (rh#1145388).
  + Moved appdata file back to top level.
  + Fixed Error Policy label content.
  + Changed GtkAlignment xalign/yalign properties to
    halign/valign on child.
  + Dropped xscale/yscale properties.
  + Dropped GtkViewport resize_mode property.
  + Converted GtkAlignment *_padding properties to
    GtkWidget margin_* equivalents.
  + Set orientation of some internal GtkBox widgets.
  + Changed GtkHBox/GtkVBox widgets to GtkBox.
  + Removed GtkAlignment widgets.
  + Refer to button label by id, not parentage.
  + jobviewer: tell monitor which printers to watch.
  + monitor: job-removed when moved out of watched set of printers.
  + jobviewer: React to button-press-event for Move To submenu
    (lp#1388601).
  + Catch IPPError when writing server settings (rh#1159584).
- Changes from version 1.5.0:
  + Don't ask PackageKit to look for drivers for empty
    device IDs.
  + monitor: only run one timer at a time.
  + Don't fill the makes list after downloadable driver
    chosen.
  + OpenPrintingRequest object for grouping queries.
  + Use items() instead of iteritems() with Python 3 dicts.
  + Use items() instead of iteritems() in
    GroupPhysicalDevicesRequest's _group().
  + Fix for automatically adding Bluetooth printers.
  + Memory leak fixes in udev-configure-printer.
  + Don't run gpk-install-package-name directly, use
    installpackage module.
  + Main window: don't try removing the populateList timer
    when not set.
  + monitor: don't try removing the update timer when not set.
- Changes from version 1.4.7:
  + Use GLib.idle_add, not GObject.idle_add.
  + Take the gdk lock before entering gtk_main() (rh#1052203).
  + Definitive postscriptdriver.prov is in pycups.
  + More Python3 fixes..
  + Fix LPD/LPR Probe (lp#1372213).
  + socket's send() takes bytes and recv() returns bytes.
  + Don't try nested classes, as CUPS forbids it (rh#1140627).
  + Moved DOWNLOADABLE_* config constants to config.py.
- Changes from version 1.4.6:
  + Explicity use /usr/bin/python3.
  + Makefiles consistent for python3.
  + Consistent use of PYTHON env var in Makefile.
  + Python3 changes for pickle handling.
  + Keep device URI field updated.
  + Codec issue fixes.
  + Always show connections for new printers when it makes sense.
  + fix resolution for unicode URIs.
  + Always display error when unable to fetch PPD for remote
    printer (rh#1087052).
  + Use urlparse for decoding DNSSD URLs.
  + Python3 syntax fixes.
  + GUI: chain up to parent constructor.
  + Prevent printer-action menu items being incorrectly sensitive
    (rh#1124284).
  + dbus: reload PPDSs in FetchedPPDS safely.
  + dbus: rewrite openprinting search as async and call destroy
    on NP dialog.
  + Revert "Don't download OpenPrinting drivers in D-Bus service
    (rh#1052203).
  + Don't call Gtk.evengs_pending() in nextNPTab (rh#1052203).
  + Explicitly use /usr/bin/python3 in udev-add-printer
    (rh#1126149).
  + More robust argument handling in udev-configure-printer.
  + Use Gtk main loop in D-Bus service (rh#1116756).
  + Fixed type causing bluetooth queues not to be removed.
  + use subprocess.DEVNULL instead of std...=file(/dev/null,...).
  + Don't set subprocess's stdout to non-writable fd.
  + Fixed __cmp__ conversion to ruch comparisons (lp#1364196).
- Adjusted BuildRequires for Python3 Port:
  + Removed: python-devel, python-xml, dbus-1-python, python-cairo,
    python-gobject, python-smbc.
  + Added: python3-devel, python3-lxml, dbus-1-python3,
    python3-cairo, python3-gobject, python3-smbc.
* Fri Oct 24 2014 dimstar@opensuse.org
- Update system-config-printer-no-openprinting.patch: do not crash
  when printing a traceback. As we disable openprinting, our
  status is always 403 and the noise of a traceback not welcome
  (boo#902407).
* Sun Jul 13 2014 dimstar@opensuse.org
- Use Adwaita-icon-theme on openSUSE 13.2 (GNOME 3.14):
  gnome-icon-theme merged the multiple subpackages and was renamed
  to adwaita-icon-theme. The presence of the icon is responsibility
  of GTK 3.
  + Conditional BuildRequires / icon location:
  - openSUSE > 13.1: adwaita.
  - openSUSE <= 13.1: gnome.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 1.4.5:
  + Some codec fixes.
  + Traceback fixes.
  + IPv6 address entry fix.
  + Auth info saving improvement.
  + Some loop/hang bug fixes.
  + Use LockButton for fewer auth dialogs.
- Rebase system-config-printer-Gtk-introspect.patch.
* Tue Mar 25 2014 fcrozat@suse.com
- Update to version 1.4.4:
  + Some UI fixes.
  + D-Bus signature decorator fix.
  + Job authentication fixes.
  + Makefile fixes.
  + Model names are now sorted by normalized name.
- Add system-config-printer-no-applet-in-gnome.patch: do not start
  printer applet in GNOME (rh#677676).
* Tue Feb  4 2014 fcrozat@suse.com
- Remove old python bindings dependencies which are replaced by
  gobject-introspection typelib ones: python-gnomekeyring,
  python-gtk, python-notify.
- Add python-cairo as dependency, was pulled before by python-gtk.
* Sun Dec  1 2013 dimstar@opensuse.org
- Update to version 1.4.3:
  + Make GnomeKeyring integration work with GIR.
  + Fix module name when retrieving item from keyring.
  + Use correct key to determine if auth is required.
  + More debug output for the OpenPrinting database query module.
  + Assign the driver type "pdf" with higher priority than the
    driver type "exact-cmd".
  + Bugs fixed: lp##653132, lp##1220066, rh##1009865, rh##1018191,
    rh##1017561, rh#1004753, rh#1003219
  + Updated translations.
* Thu Nov 28 2013 dimstar@opensuse.org
- Add system-config-printer-Gtk-introspect.patch: Require Gtk 3.0
  typelibs. We know we can't use Gtk 2.0 (bnc#852450).
- Require system-config-printer from -applet instead of only
  system-config-printer-common (bnc#852842).
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 1.4.2:
  + Bugs fixed: rh#998277, rh#994506, rh#989096, rh#989050,
    rh#986939, rh#984284, rh#957733, rh#979119, rh#978970,
    rh#975705, rh#975058, rh#974845, rh#973662, rh#971973,
    rh#971404, rh#971548, rh#971459, rh#971417, rh#970646,
    rh#969846, rh#968142, rh#965771, rh#962207, rh#964673,
    rh#965678, rh#957444, rh#961882, rh#965678.
* Fri May 10 2013 dimstar@opensuse.org
- Update to version 1.4.1:
  + Make man page and --help output consistent.
  + Bugs fixed: rh#957343, rh#957444, rh#951710, rh#915483,
    rh#950162, rh#948240.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 1.4.0:
  + Support for firewalld.
  + Use gi.repository throughout.
  + Removed old bits (gtk_label_autowrap and gtkspinner).
  + Some locking fixes.
- Drop system-config-printer-fix-name-of-udev-helper.patch: fixed
  upstream.
- Rebase system-config-printer-no-openprinting.patch.
- Add gobject-introspection BuildRequires: needed to get automatic
  typelib() requires.
* Mon Feb 11 2013 coolo@suse.com
- Add system-config-printer-fix-name-of-udev-helper.patch to fix
  udev-configure-printer to be called at all.
* Thu Nov 29 2012 dimstar@opensuse.org
- Add python-pycurl Requires to python-cusphelpers subpackage, as
  pycurl is imported from cupshelpers/openprinting.py.
* Mon Nov  5 2012 tittiatcoke@gmail.com
- Ensure that the udev related files are installed in the correct
  path (/usr/lib/udev).
* Tue Oct  9 2012 dimstar@opensuse.org
- Update to version 1.3.12:
  + Fixed udev rules so a systemd service is created for the device
  + Cleaned up systemd service description.
  + udev: Allow remove to take the same format address.
  + Catch-all for gnomekeyring exceptions (bgo#859760).
- Fix %%post/%%postun scripts to reference the new service name (and
  do not handle demo.service; an obvious copy/paste error).
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 1.3.11:
  + Fixed most recent change in cupshelpers: The cupshelpers config
    module was not being imported.
* Thu Aug  2 2012 dimstar@opensuse.org
- Update to version 1.3.10:
  + Changed application name in desktop file
  + Use cups-config to determine serverbin directory
  + Improved sorting of device lists
  + Add "--show-jobs" command line option
  + Use hpcups instead of ps with HP LaserJet 12xx/13xx
  + Suppress misleading notifications (lp#855379)
  + PDF printer support
  + Various enhancements on udev-configure-printer.
- Replace libudev-devel and libusb-compat-devel BuildRequires with
  pkgconfig(libusb-1.0), following upstreams change.
- Add pkgconfig(libudev) BuildRequires: it was pulled in implicit
  before.
* Fri Jul 20 2012 dimstar@opensuse.org
- Pass --with-systemdsystemunitdir=%%{_unitdir} to configure to
  have the systemd service files installed
- Add systemd BuildRequires in order to have the %%{_unitdir} macro
  defined
- Drop xz BuildRequires, as it now comes for free with the build
  system.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 1.3.9:
  + Improved output from check-device-ids script.
  + Don't warn about changed cupsGetPPD3 behaviour in CUPS 1.5.3.
  + Avoid temporary file leaks.
  + Handle file disappearances when caching PPDs (rh#786232).
  + Fixed several debugprints (rh#785581).
  + Updated translations.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 1.3.8:
  + Use pycurl 'https' support for openprinting (CVE-2011-4405)
  + Really fix SMB probing in PrinterFinder.
  + Require newer pycups; drop compatibility code.
  + Don't penalise pxlmono now that rh#661814 is fixed in
    ghostscript-9.04
  + Several fixes related to cups authentication.
  + Various other code changes.
  + Bugs fixed: rh#743446, rh#751610, rh#755913, bgo#757520,
    rh#772112, bnc#735322, lp#653132, lp#653132, lp#653132,
    lp#844976, lp#874445, lp#653132.
  + Updated translations.
- Drop system-config-printer-subprocess-no-shell.patch: fixed
  upstream.
- Rebase system-config-printer-no-openprinting.patch.
* Tue Jan  3 2012 vuntz@opensuse.org
- Fix coding errors caught by Stephen Shaw <stshaw@suse.com> in
  system-config-printer-subprocess-no-shell.patch.
* Thu Dec  8 2011 vuntz@opensuse.org
- Add system-config-printer-subprocess-no-shell.patch: avoid
  escaping issues when running commands. Fix bnc#735322.
* Tue Dec  6 2011 vuntz@opensuse.org
- Add system-config-printer-no-openprinting.patch: this disables
  the feature where PPD drivers can be downloaded from
  OpenPrinting.org. See discussion in bnc#733542. As a side-effect,
  this fixes CVE-2011-4405.
* Wed Oct 26 2011 badshah400@gmail.com
- Modified categories in .desktop file so that it is grouped with
  "System" applications in the desktop menus (bnc#714333)
* Thu Oct  6 2011 vuntz@opensuse.org
- Update to version 1.3.7:
  + Show private job attributes for "my jobs" (rh#742279).
  + Enable Test Page button when application/postscript is
    supported.
  + Some preferreddrivers.xml fixes (lp#855412).
  + Handle errors saving troubleshoot.txt (lp#789602).
  + Removed some stale code.
  + Make connections list more easily accessible (lp#842092).
  + Improved handling of remote CUPS queues via DNS-SD, and IPP
    devices.
  + Better display of CUPS servers from "Find Network Printer".
  + Fixed SMB method for printer finder.
  + Don't handle tooltips during mainloop recursion (rh#664044,
    rh#739734).
  + Fixed bold print of tab labels on option conflicts.
  + Preserve installable options on driver change.
  + Update printer properties dialog correctly when PPD changed.
  + Fixed typo triggered by private job attributes (lp#827573).
  + Marked some translatable strings that weren't (rh#734313).
* Tue Sep  6 2011 vuntz@opensuse.org
- Split the main subpackage in various smaller subpackages, to
  enable more fine-grained dependencies (gnome-control-center only
  needs the dbus service, and we don't want to force people to
  install the whole system-config-printer in that case):
  - Create common subpackage that contains files common to more
    than one subpackage.
  - Create applet subpackage that contains the notification icon
    monitoring printing stuff when the user is logged in.
  - Create dbus-service subpackage that contains the dbus service.
  - Rename lang subpackage to common-lang, so that it gets
    installed with the common subpackage.
  - Make all those subpackages depend on the common subpackage, for
    obvious reasons.
  - Add other dependencies between those subpackages:
    . Add applet subpackage Recommends to main subpackage: it makes
    sense to have the applet if the main tool is installed.
    . Add dbus-service subpackage Requires to applet subpackage:
    the applet relies on the dbus service to manage jobs.
  - Move dbus-1-python, python-cups, python-cupshelpers,
    python-gnomekeyring, python-gobject, python-gtk, python-notify,
    python-smbc Requires from main subpackage to common subpackage
    since all those python modules can be used by the various
    tools.
  + Remove unneeded dbus-1-x11 and desktop-file-utils Requires.
  + Add a system-config-printer-applet Recommends to
  udev-configure-printer: the udev tools create a notification for
  the user if the applet is installed.
  + Make python-cupshelpers noarch.
  + Move the com.redhat.PrinterDriversInstaller.conf dbus
  configuration file to python-cupshelpers, where it really
  belongs (since this is where the dbus server is implemented).
  + Drop support for openSUSE <= 11.1.
* Thu Aug 25 2011 dimstar@opensuse.org
- Update to version 1.3.6:
  + Allow entering @,?,=,& characters in Device URI text field
    (lp##826958).
  + IPPAuthConnection: avoid traceback (Ubuntu #828030).
  + Removed PackageKit client code in missingPackagesAndExecutables
    (lp#726938).
  + Properties dialog: make OK button sensitive even when no
    changes to save (lp#444280).
  + Updated translations.
* Wed Aug 24 2011 badshah400@gmail.com
- Also provide icon of size 256x256 (bnc#713902)
* Sat Jul 30 2011 vuntz@opensuse.org
- Update to version 1.3.5:
  + Expose more things via D-Bus: driver selection, missing
    executables checking, and physical device grouping.
  + Bug fixes:
  - Fixed cupsFilter search in missing executables check.
  - Use PackageKit to resolve missing executable filenames to
    packages, instead of having a static mapping in the source
    code.
  - Fixed DNSSD hostname resolution.
  - Fixed firewall code to handle json errors when used with the
    older system-config-firewall D-Bus service.
  - Fixed LPD probing (rh#726383).
  - Use "hostname" instead of "IP address" when asking for names
    of browse servers (rh#726134).
* Sun Jul 17 2011 dimstar@opensuse.org
- Update to version 1.3.4:
  + udev:
  - Don't rely on retriggering printers; enumerate them from
    systemd instead.
  - Don't complain about missing/invalid device ID for devices
    we've already handled.
  + UI:
  - Removed unused Printer Groups feature.
  - Don't show "No printers configured" page if the printers are
    filtered in any way.
  - URL-quote URIs when using "Find Network Printer" (lp#808137).
  - Downloadable drivers: don't display printers for which there
    are no drivers (rh#668154).
  - Kerberos support for the SMB 'Verify' button (requires new
    enough pycups).
  - Removed IPP/HTTP device screen in favour of "Enter URI"
    (rh#685091).
  - Converted ComboBoxEntry widgets to Entry+EntryCompletion in
    NewPrinterWindow.ui.
  - Robustness in ppdsloader in the face of errors (lp#766818).
  - Changed Make/Model/State labels into GtkEntry widgets so
    contents are always fully selectable (rh#719217).
  - Convert iters to paths before comparing (rh#717062,
    lh#791690, trac#221).
  - Set translation domain in D-Bus service (lp#783967).
  - Ensure consistency in jobviewer if add_job fails (rh#693055,
    rh#632551).
  + Driver preferences:
  - Avoid PostScript for HP LaserJet 2100 Series (rh#710231).
  - Raised priority for SpliX driver (lp#793741).
  + Other:
  - Adjusted test code in asyncpk1.py so it doesn't look like a
    tempfile vulnerability.
  + Updated translations.
- Add xz BuildRequires to be able to decompress the tar.xz source.
* Sat Jul  2 2011 dimstar@opensuse.org
- Move %%{_sysconfdir}/cupshelpers/preferreddrivers.xml to
  python-cupshelpers subpackage as the file is from there.
- Own %%{_sysconfdir}/cupshelpers to fix build.
* Thu Jun  9 2011 vuntz@opensuse.org
- Remove python-gnome Requires as no modules from python-gnome are
  used.
- Add missing python-gnomekeyring Requires.
- Change python-gobject2 Requires to python-gobject, following the
  package renaming.
* Fri Jun  3 2011 dimstar@opensuse.org
- Update to version 1.3.3:
  + Main application:
  - Allow %% character in SMB URI (lp#747400).
  - More error handling (lp#744783).
  - Avoid traceback if printer duplication fails (rh#694629).
  - Fixed off-by-one error in monitor.
  - Fixed printer renaming (lp#726954).
  + Printer Properties dialog:
  - Added PrinterModified D-Bus signal to printer properties
    interface.
  - More robustness for printer properties dialog when printer
    removed (lp#741987).
  + New Printer dialog:
  - Fixed PPDs loader when using CUPS remotely or when DBus not
    available (rh#693515).
  - Handle failure to load PPDs more gracefully (lp#742409).
  - Avoid traceback when cancelling New Printer dialog after
    failure.
  - Make sure everything is ready before handlers might be called
    (rh#689336).
  + Job Viewer:
  - Ensure consistency in jobviewer if add_job fails (rh#693055,
    rh#632551).
  - Be defensive against CUPS returning incorrect job IDs
    (lp#721051).
  + Other bits:
  - More uses of check-device-ids.py.
  - udev-configure-printer: be more defensive when parsing CUPS
    response (lp#760661).
  + Other bugs fixed: lp#733088, lp#748964, lp#759811, lp#777188.
  + Updated translations.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 1.3.2:
  + Main application:
  - rh#685098: Set connected state when connecting to server
    fails
  - Handle the situation where cupsd has died/restarted more
    gracefully.
  - Renamed ui/*.ui -> ui/*.glade again, fixing translations.
  + Printer Properties dialog:
  - lp#729966: Just hide Printer Properties dialog on
    delete-event
  - Extra job options: print-quality, printer-resolution,
    output-bin.
  - Automatically show horizontal scrollbar in job options screen
  - Ignore "output-mode-default" attribute as it is not settable.
  - Handle IPP_TAG_RESOLUTION types (requires pycups-1.9.55).
  - Don't traceback if option value cannot be handled.
  - rh#679103: Fixed traceback in options.py
  + New Printer dialog:
  - rh#685091: Handle URIs in Find Network Printer entry, and use
    'Enter URI' instead of 'Other'
  - trac#213: Use "Do It Later" instead of "Cancel" for adjust
    firewall dialog
  - rh#680683: Fixed an instance where NewPrinterGUI might not
    have self.printers set
  - IPPHostname can contain colon (to specify port).
  - Fixed automatic driver installation when changing the driver.
  - Removed stale code left over from conversion to gobjects.
  - Ensure all uses of ppdsloader supply the Device ID.
  - Fixed some small typos in newprinter --help output.
  - rh#680288: Prevent traceback after 2nd drivers search dialog
    is cancelled
  + Driver handling:
  - Activated and fixed testing mode for device ID/driver
    association
  - Match HP-Fax2/3/... PPDs, as well as Ubuntu/Debian hpijs-ppds
    packages.
  - preferreddrivers.xml: Identify hpcups and hpijs fax PPDs.
  - Match native hpijs driver (drv:///hp/hpijs.drv/...) as hpijs.
  - Handle Ubuntu locations of hpcups.drv and hpijs.drv.
  - preferreddrivers.xml: match OpenPrinting gutenprint PPD names
    as gutenprint.
  - Removed DES field check altogether.
  - xmldriverprefs.test: show order more clearly.
  - Make xmldriverprefs.test() debugging optional.
  - More debugging during PPD selection.
  - Prefer foomatic PostScript drivers before PCL drivers (except
    foomatic-recommended ones).
- Update to version 1.3.1:
  + Fixed traceback due to libsane-hpaio installation check.
  + Removed duplicate method definition.
  + Defer calls to populateList initiated by monitor.
  + firewall: fixed cache behaviour.
  + Fixed page sequence when adding a printer with an
    exactly-matching driver.
- Update to version 1.3.0:
  + Only show maintenance buttons when capable (rh#658564).
  + Compare printer make/model names only by words and numbers
    (like they sound).
  + XML-based driver preference rules.
  + Don't use status icon when notification server supports
    persistence.
  + Fetch Device ID for existing device when changing PPD, allowing
    a more complete choice of drivers.
  + Include generic drivers as candidates whenever CMD field is
    available.
  + Show all ID-matched drivers when adding a new printer.
  + Speed-ups in cupshelpers.ppds.ppdMakeModelSplit.
  + PPDs: Use ppd-product values to add to make/model list.
  + Show number of processing / pending jobs (rh#606868).
  + PPDs are now cached, with support for If-Modified-Since.
  + Adjust the firewall for SMB browsing.
  + Start CUPS service if not already started (rh#577226).
- Rebase system-config-printer-icon-brp-friendly.patch.
- Drop system-config-printer-firewall-menu.patch: no longer needed.
  This means we can remove the gnome-patch-translation
  BuildRequires.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 1.2.5:
  + Do not accept some invalid characters in various entries.
  + Add examples of IPP URI to NewPrinterWindow (rh#575795).
  + Delete Bluetooth printer's queue when unpaired.
  + Create ~/.printer-groups.xml only when group is created.
  + Add CMD-field matching for PPDs (rh#630058).
  + Save name of PPD which matches best to the detected printer,
    not only make/model.
  + Mark more strings as translatable.
  + Fix some crashes.
  + Small improvements and fixes.
  + Updated translations.
* Tue Aug 24 2010 dimstar@opensuse.org
- Update to version 1.2.4:
  + udev helper: use CUPS defaults when connecting.
  + Blacklist certain printer state reasons (rh#520815).
  + Exclude dnssd backend from udev search.
  + Do not error out on missing firewall D-Bus service.
  + Prioritize HP's hpcups driver against HPIJS.
  + Improvements for setting up Bluetooth printers.
  + udev-configure-printer: Match usblp, libusb, HPLIP, and USB
    device file URIs.
  + Fill the queue list when clicking "Probe" in LPD printer setup
    screen.
  + Remove the ":9100" from discovered "socket://..." URIs.
  + Integration of the dnssd CUPS backend and assosiation of DNS-SD
    names and IPs.
  + When setting up a printer search for local drivers before
    searching the internet.
  + Access OpenPrinting via the web query API with redirect
    support.
  + Prioritize DNS-SD-based URIs against IP-based URIs.
  + On discovered network printers do not only cache make and model
    but also the device ID.
  + Fix recognition of remote CUPS queues when setting up an IPP
    queue.
  + Avoid connecting to cups twice in PPDsLoader.
  + Make udev-configure-printer work for Bluetooth.
  + rh#618357: Changed shebang in executables
  + Various other bug fixees.
  + Updated translations.
- Rebase system-config-printer-icon-brp-friendly.patch
* Sat Aug  7 2010 vuntz@opensuse.org
- Clean up update to 1.2.3.
- Force installation of udev rules and helpers in /lib/udev instead
  of /etc/udev, since the default is to put a binary in /etc/udev,
  which is wrong.
* Wed Jul  7 2010 dimstar@opensuse.org
- Update to version 1.2.3:
  + Add Bluetooth auto-config to udev-configure-printer.
  + Make sure automatically-created queues will work.
  + Don't add queues for Graphtec devices.
  + Use sysconfdir for udev rules.
  + UI improvements.
  + Bug fixes.
  + Updated translations
- Changes from version 1.2.2:
  + Resolve DNS-SD hostnames for physical device comparison.
  + Handle connection failures to cups better.
  + UI improvements.
  + Bug fixes.
  + Updated translations
- Changes from version 1.2.1:
  + Many improvements in check-device-ids.
  + Use cups-pk-helper method for canceling jobs.
  + Add 25%%, 50%% and 75%% level markers in the inklevel widget.
  + Improve Firewall interaction (Fedora-specific).
  + Fix a few crashes.
  + Bug fixes.
  + Updated translations
- Add glib2-devel BuildRequires.
- Rebase system-config-printer-icon-brp-friendly.patch.
* Thu Mar 18 2010 dimstar@opensuse.org
- Update to version 1.2.0:
  + The my-default-printer application has been removed.
  + Printer drivers are automatically installed when possible.
  + The basic/advanced server settings dialogs have been merged.
  + PPDs are now fetched asynchronously.
  + The job viewer has seen many improvements.
  + Updated translations.
- remove fixme regarding polkit-1: current configure would not
  even know about it.
- Rebase system-config-printer-icon-brp-friendly.patch to apply
  without fuzz.
* Sat Feb 27 2010 dimstar@opensuse.org
- Update to version 1.1.93:
  + Display a warning when the wrong IEEE 1284 ID is detected
  + rh#566938: catch RuntimeError in statereason.py when
    cupsGetPPD2 fails
  + Removed HP and Kyocera IEEE 1284 Device ID hacks
  + Increased new printer notification timeout to 20 minutes.
  + Added simple program to check IEEE 1284 Device IDs against PPDs
  + Update translations.
* Sun Feb 21 2010 dimstar@opensuse.org
- Update to version 1.1.92:
  + system-config-printer:
  - Use stock 'add' icon for new-printer button (lp#394071)
  - Use gtk.STOCK_ instead of gtk- throughout
  - Avoid clearing selecting device settings when adding a
    printer
  - Update the PolicyKit code to use the correct signature for
    DeviceGet
  - ppsloader: avoid traceback
  - Set timeout for InstallPrinterDrivers D-Bus call
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 1.1.91:
  + system-config-printer:
  - Make it obvious when a printer is disabled.
  - Update 'Time submitted' column when clicking Refresh in job
    viewer.
  - Fixed traceback when renaming a printer.
  - Fixed async pycups fallback again.
  - Fixed statereason localization for raw queues (rh#558156).
  - Set model for LPD queue ComboEntry.
  - Only add current device to list when all devices found
    (rh#558524).
  - When retrying authentication as another user, forbid
    PolicyKit.
  - Use tooltips in jobs treeview.
  - Avoid non-zero page sizes in SpinButton adjustments.
  - Only show jobs for selected printers in job viewer.
  - Better error handling when renaming a printer (rh#561182).
  - Troubleshooter checks local SELinux file contexts.
  - Fixed drop-down list for connection dialog.
  - Avoid crash filling makes list when no make detected
    (rh#562520).
  - Fixed automatic driver assignment via applet.
  - Minor bugfixes and HIG fixes.
  + Updated translations.
* Wed Jan 20 2010 vuntz@opensuse.org
- Update to version 1.1.90:
  + system-config-printer:
  - Parse foomatic's special DRV Device ID field (rh#550108).
  - Driver selection fixes (rh#550075).
  - Remove my-default-printer application.
  - Handle cancelJob's optional purge_job parameter in PolicyKit1
    backend.
  - Changed 'Clear job' to 'Delete job'.
  - Make sure the printer we added still exists before selecting
    it (rh#551436).
  - Set notification timeouts appropriately (rh#550829).
  - "Copy" action in context menu is now called "Duplicate".
  - Make sure there are enough ink level values (rh#541882).
  - Reinstated job completion notifications with better text.
  - Remove job attributes viewer tabs for jobs that have been
    purged.
  - Use asyncconn for canceling/deleting jobs.
  - Ability to retrieve job files which have been preserved.
  - Set D-Bus timeout when calling asynchronously.
  - Restore option values for serial device.
  - Fixed window modality and transience.
  - PrinterDriversInstaller implementation: this is a system bus
    service to install drivers via PackageKit.
  - Use asyncconn to fetch PPDs.
  - Don't rely on cups-pk-helper being around (rh#556170).
  - Make sure serial device widgets are always initialized
    (rh#556488).
  - Clean up temporary files when localizing statereason
    (rh#552768).
  - Removed support for installing HP's proprietary plug-in.
  - Fix various tracebacks (rh#550442, rh#550437, rh#553141,
    rh#554372, rh#554268, rh#555552).
  - Avoid leaking resources.
  - Code cleanups.
  - Updated translations.
  + udev-configure-printer/udev-add-printer:
  - avoid traceback when no CMD field present.
  - try to install drivers first.
- Update system-config-printer-icon-brp-friendly.patch after
  my-default-printer removal.
- Remove system-config-printer-hide-my-default-printer.patch:
  my-default-printer was removed.
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 1.1.16:
  + system-config-printer:
  - Don't fail if smbc module is not available.
  - Don't overwrite BrowsePoll settings with basic settings
    dialog (rh #543986).
  - Fixed cupsd.conf parsing when lines begin with blanks
    (rh#544003).
  - Constraints handling fix.
  - Clear device screen each time a new dialog is presented.
  - Prefer Foomatic/hpijs to hpcups for the time being.
  - Rearchitecture code for more asynchronous code, and use it to
    fetch the device list in a safe way.
  - Adapted to new pycups API for cupsSetPasswordCB2.
  - Ignore com.apple.print.recoverable state reason.
  - Fix various tracebacks.
  + Updated translations.
* Wed Dec 16 2009 vuntz@opensuse.org
- Update to version 1.1.15:
  + system-config-printer:
  - Fix a traceback.
  - Don't update properties if apply failed (rh#542503).
- Changes from version 1.1.14:
  + system-config-printer:
  - Avoid unnecessary "publish printers" dialog.
  - Translate job-hold-until and retry-current-job values.
  - Attempt to discover whether the firewall needs adjusting.
  - Iconify jobs window into status icon.
  - Handle hpcups driver for 5400 series in test suite.
  - Added SMB support to 'Find Network Printer'.
  - Fixed device fetch when not using polkit-1.
  - Cancel PrinterFinder when new-printer dialog closes.
  - Added IPP and JetDirect support to 'Find Network Printer'.
  - Use the correct URI for probed CUPS queues.
  - Better order for network printer probes.
  - Use make-and-model to guess the PPD driver for a discovered
    printer, if no device ID is available.
  - Improve default name of printer, when the name already
    exists.
  - Auto-select raw queue correctly when changing PPD.
  - Attempt to determine make and model of network printers
    (rh#524321).
  - Don't display properties dialog for first test page
    (lp#444280).
  - Fixed visibility tracking for jobs window.
  - Strip 'zjs', 'zxs', 'pcl3' from make-and-model (rh#531048).
  - Added support for custom state reasons.
  - Catch IPP errors when updating from notified events
    (rh#530641).
  - Fail nicely if new printer is deleted during test page prompt
    (rh#533109).
  - Suggest installing foomatic-db-ppds when appropriate.
  - Install the foomatic package if foomatic-rip is missing.
  - Retry when reconnection (due to authentication) fails
    (rh#541741).
  - Various small bug and UI fixes.
  - Various code improvements.
  - Fix various tracebacks.
  + udev-configure-printer/udev-add-printer:
  - Build system fixes.
* Sat Oct 10 2009 dimstar@opensuse.org
- Update to version 1.1.13:
  + system-config-printer:
  - Use correct statereason level icon names.
  - Handle icon load failure gracefully.
  - Fix cleaning of TurboPrint PPD listings of CUPS 1.4.x.
  - Avoid error dialog after cancelling operation via PolicyKit
    dialog.
  - Fetch devices in a separate thread to avoid blocking
    (lp#516787).
  - Add polkit-1 support, and make it conditional on "configure
  - -with-polkit-1".
  - Fixed traceback with older versions of GTK+.
  - Fixed proxy authentication.
  - Allow PPD/device changes for raw queues.
  - Extended TimedOperation class to allow callbacks
  - Fixed cupspk support for DevicesGet
  - Allow parameters to cupshelpers.getDevices
  - Allow for more than one spinner task
  - Use callbacks when fetching devices
  - Fixed spinner UI bug
  - Fixed cancellation in TimedOperation class
  - Fetch network devices as soon as local devices are received
  - Make sure to cancel the fetchDevices callback when not needed
  + Updated translations.
- Rebase system-config-printer-firewall-menu.patch to apply with
  fuzz=0.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 1.1.12:
  + system-config-printer:
  - Don't get tripped up by "-" when checking for missing
    executables.
  - HP's Bluetooth printers return a model name with added "_BT"
    in their device ID.
  - Added support for localized marker names
  - Fixed parenting of WaitWindow when adding printer.
  - Don't attempt to use PolicyKit if we are root.
  - Support for cups-pk-helper's DevicesGet method.
  - Use modern gtk tooltip support.
  - Fixed typo handling exceptions from
    AdvancedServerSettingsDialog.
  - Use set_default_size instead of setting width and height
    properties.
  - Fixed missing treeview update in properties dialog.
  - Fixed identification of CUPS native gutenprint drivers.
  - Prefer native CUPS drivers to foomatic drivers.
  - Busy/ready cursor handling fixes.
  - Use separate thread for verifying IPP queue.
  - Set an appropriate status icon tooltip when configuring
    printer.
  - Fixed cupspk handling of disabling a printer.
  - Show a 'paused' emblem for disabled printers.
  - Use preferred object path for AuthenticationAgent.
  - Kill job creation times timer on the jobviewer is destroyed.
  - Only update job creation times once per minute at rest.
  - Job status icon and state reason in jobs treeview.
  - Show rejecting printers as insensitive.
  - Added experimental package tagging for PPD files.
  - Removed notification when job has completed.
  - Fixed applet traceback when printing test page.
  - Don't allow Back/Forward to lose troubleshooting diagnostic
    information.
  - Code cleanups.
  + udev-configure-printer/udev-add-printer:
  - Compare MFG and MDL case-insensitively.
  + Updated translations.
* Sat Aug  8 2009 vuntz@novell.com
- Update to version 1.1.11:
  + udev-configure-printer/udev-add-printer:
  - don't add fax queue if already present
  - don't fork if DEBUG environment variable set
  - Enable/disable queues with paired device URIs
  - use '/' as delimiter when examining device URI
  - make sure we don't configure the same printer twice
  - Don't set USB configuration in udev-configure-printer
  - Serialize CUPS-Get-Devices requests
  - Exit early in udev-configure-printer if device already mapped
    to URIs
  - don't require pycups 1.9.46 just yet
  - Fixed name uniqueness checking
  - Notify the correct printer name
  - create fax queues using prefix of printer queue
  - fixed duplicate devpath check
  - fixed removal when cupsd not running
  + system-config-printer:
  - Use case-insensitive matching when cleaning up the PPD nick
    names to get the model names for the make/model/driver list
  - Made extracting make and model from the NickName of
    TurboPrint PPDs working again
  - Made the field for freely typing in an URI actually work
  - Better method of determining current device URI
  - Printer icon should not show 'printing' when job stopped
  - Updates for hplip 3.9.6
  - Let the checks for adding a device to a physicaldevice object
    parse HPLIP URIs correctly to extract the host name/IP from
    them
  - jobviewer: notice jobs that have stopped due to backend
    errors
  - Fixed cupspk's implementation of adminGetServerSettings()
  - A warning is given that renaming destroys print job history
  - Small improvements for printer rename confirmation
  - API improvement in cupshelpers: limit job fetches
  - troubleshoot: treat http and https schemes as potential CUPS
    servers
  - Make properties dialog OK button insensitive when no changes
  - Validate BrowsePoll entries
  + Code cleanups and plug leaks.
  + Updated translations.
* Wed Aug  5 2009 vuntz@novell.com
- Fix build on 11.1 and earlier: we don't want the udev helpers
  there.
* Thu Jul 23 2009 vuntz@novell.com
- Update to version 1.1.10:
  + Support for HPLIP 3.9.6.
  + Fixed 'location' field for printers added remotely.
  + Avoid traceback when adding new printer.
  + Parse nmblookup failures correctly.
  + Avoid non-fatal traceback when adding IPP printer.
  + Make sure we find https URIs from https backend.
  + Prevent traceback on IPP notification after properties dialog
    cancelled.
  + Fixed incorrect authentication in the troubleshooter.
  + Arrows for adding and removing class members are sensitive only
    if something is selected.
  + Small fix for class members arrows: always de-sensitise buttons
    after use.
  + Another fix for selecting an added printer.
  + Spot stopped jobs with CUPS 1.4 as well.
  + Map gutenprint filenames to the package name.
  + Use gpk-install-package-name to install packages, not the PK
    D-Bus API.
  + Always update the jobviewer status icon on job events.
  + Fixed UI oddities when changing PPD/device.
  + Avoid possible traceback when receiving printer-added-events.
  + Fixed initial radio button selection for SMB authentication.
  + Make sure to URL-encode usernames and passwords correctly.
  + Don't run Properties dialog on new printer.
  + Don't mention the job number in completed jobs notification.
  + Check exit codes for child processes.
  + Removed IPP browser.
  + Improved matching of printer model names.
  + Added PIXMA comment to test suite.
  + Efficiency fixes for PPDs Device ID matching.
  + Fixed --debug option for PPDs self-test function.
  + Efficiency and readability improvements in PPDs Device ID
    matcher.
  + Avoid cups.setServer/setPort.
  + Fixed incorrect "printer not shared on server" message.
  + Drop libsexy support in favour of GTK+ 2.17's equivalent.
  + Avoid reloading all PPDs when calls to jockey fail.
  + Small speed-up (0.09s) for the case where jockey is not
    present.
  + Don't reload all PPDs if the query has already finished.
  + 75%% speed improvement in ppdMakeModelSplit().
  + New udev-based queue configuration system.
  + Improve window size.
  + Fixed hang on start-up when trying to resize the window.
  + Fixed tracebacks in cupshelpers.ppds test suite.
  + Fixed Device ID matching for HPLIP PPDs.
  + Updated translations.
- Add cups-devel, libudev-devel, libusb-compat-devel BuildRequires.
- Pass --with-udev-rules to configure.
- Package the udev helpers in udev-configure-printer. This package
  Obsoletes cups-autoconfig, since the new udev helpers now do this
  job.
- Split cupshelpers python module in python-cupshelpers package
  since it's needed by udev-configure-printer.
- Drop system-config-printer-cups-autoconfig-notifications.patch:
  we will now use the udev tool and we will receive notifications
  without this patch.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 1.1.8 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Set relaxed PPD conformance
  + Fixed URI parsing when verifying IPP URIs
  + Set glade's textdomain in the jobviewer (lp#341765)
  + Made hp-plugin call also working with HPLIP 3.9.2
  + Adjusted border padding for New Printer window
  + Use ValueError in PhysicalDevice to indicate device is
    different
  + Import debugprint in cupspk
  + Fixes on automatic printer model selection and suggestion of
    queue name
  + Style and efficiency improvements
  + Fixed XmlHelper crash on invalid XML file (lp#370469)
  + Clean up temporary PPD files when we're finished with them
  + Reconnect to CUPS if the connection gets lost during the
    installation of a driver from OpenPrinting
  + Scroll to new job if it was added just above the visible range
  + Use grey ink-drop when there is no marker-colors value
  + Fixed conversion from broken-down UTC time to simple UNIX time
    for held jobs
  + Track printer state changes for the printer context menu
  + Removed some stale code in cupshelpers
  + Make sure the job context menu cannot get out of date
  + Select a newly-added printer
  + Make troubleshooter work again by disabling cupspk for it
* Wed Apr 15 2009 vuntz@novell.com
- Update to version 1.1.7 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Prevent some tracebacks
  + Various improvements for printer model identification
  + Added support for https device URIs showing the IPP screen
  + Efficiency fixes
  + Do not use setlocale() for locale-independent
    uppercase/lowercase conversion
  + jobviewer: don't abort if we couldn't show a notification
* Sat Mar 14 2009 vuntz@novell.com
- Update to version 1.1.6 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Use setlocale() to save current LC_CTYPE value, not getlocale()
  + Don't try search for a model series if there are no digits in
    the model name
  + Adapted D-Bus policy file to the new D-Bus defaults
  + Better PPD fallback searching.
  + Strip " hpijs" from PPD names.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 1.1.5 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + UI improvements in the new printer dialog.
  + Include local printer attributes in diagnostic output.
- Drop system-config-printer-bnc456110-non-blocking-probe.patch:
  fixed upstream.
- Drop system-config-printer-fix-add-printer-git051bc7f0.patch:
  fixed upstream.
* Thu Feb 26 2009 vuntz@novell.com
- Add system-config-printer-fix-add-printer-git051bc7f0.patch:
  patch from git to fix the "Add printer" dialog not working.
* Tue Feb 24 2009 vuntz@novell.com
- Add system-config-printer-bnc456110-non-blocking-probe.patch:
  make the probing code non-blocking for the UI.
  Fix bnc#456110.
* Mon Feb 23 2009 vuntz@novell.com
- Add system-config-printer-firewall-menu.patch: fix string to
  mention the correct path in menus to access the firewall tool.
  Fix bnc#442106.
- Use gnome-patch-translation for the new string.
  (Thanks to Stanislav Brabec for this)
* Sat Feb 21 2009 vuntz@novell.com
- Update to version 1.1.4 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Don't display status icon for completed jobs
  + Only add job to the active set if it is active; otherwise,
    remove it from the set if it is there.
  + If the emptiness of the active set has changed, update the
    status icon.
  + Handle D-Bus failures when connecting to the session bus
    (Jockey) (rh#484402)
  + Don't show wait window when adding a new printer, as that may
    require an authentication dialog and we don't want them
    competing for focus (rh#484960)
  + Don't grab keyboard and pointer when displaying authentication
    dialog. Instead let the window manager prevent keyboard input
    accidentally going to the wrong window.
  + Don't display a notification when authentication is required,
    just go straight to the authentication dialog. Don't grab
    keyboard and pointer for that dialog and instead let the window
    manager prevent keyboard input accidentally going to the wrong
    window.
  + Otptions: Check constraints in reverse as well, so that
    constraint checking is symmetrical.
  + Don't allow PPD changes when there are conflicts
  + Support for auto-detection of printers vis hal-cups-utils
    without hal-cups-utils creating a queue, especially if there is
    no driver specifically assigned to the detected printer.
  + Skip selection of manufacturer, model, and driver in the
    new-printer wizard if an exact driver match has been found.
  + Added functionality to automatically recognize whether the
    proprietary plug-in of HPLIP is useful or even required and to
    ask the user whether he want to download and install it.
  + Fixed "hp-info" calls: There should be no space between "-d"
    and the "URI" to work around HPLIP option parsing bug.
  + Return None if the "fax-type" is 0, this means that fax is not
    available on the given printer.
  + Fixed switch between the notification for the case that a queue
    got created and the case that no queue got created.
  + Perform lowercase operations in locale-independent manner.
  + Merge cups-pk-helper branch.
  + Updated translations.
- Split cups-pk-helper and pysmbc in their own packages.
- Remove BuildRequires because of the split: PolicyKit-devel,
  cups-devel, dbus-1-glib-devel, epydoc, gtk2-devel,
  libsmbclient-devel.
- Remove BuildRequires: gettext-devel.
- Add Requires on python-smbc.
- Add Recommends on cups-pk-helper.
- Drop system-config-printer-policykit.patch: accepted upstream!
- Drop system-config-printer-more-checks.patch: upstream improved
  the PolicyKit support to not require this.
- Drop system-config-printer-python-prefix.patch: was needed only
  for pysmbc.
- Do not call autoreconf anymore.
* Thu Feb  5 2009 vuntz@novell.com
- Drop system-config-printer-install-python.patch after discussion
  on opensuse-packaging. Update the file list accordingly.
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 1.1.3:
  + Refresh server settings when the advanced server settings
    dialog has finished.
  + Better default height for jobs window.
  + Put waiting cursor when filling make/model lists.
  + Find parent window to set Conflicts dialogtransient for.
  + Various fixes for conflicts button.
  + Fix the potential dbus security issue with send_interface
  + Fixed traceback while fetching hpfax device ID (lp#321139)
  + Use authenticated	connection, except when printing the test
    page.
  + Don't make the troubleshooter window transient for the main
    window (rh#481505)
- Drop system-config-printer-bnc468379-dbus-send-dest.patch: fixed
  upstream.
- Respin system-config-printer-install-python.patch.
* Sun Feb  1 2009 mboman@suse.de
- Update to version 1.1.2:
  + Prevent traceback.
  + Collapse/expand device rows on activation.
  + Avoid traceback with raw queues.
  + Added accessibility relations
  + Handle notification closure for re-connected printers correctly.
  + Advertise correct defaults for page-left, page-right, page-top and
    page-bottom job options (rh#468553).
* Tue Jan 27 2009 vuntz@novell.com
- Update to pysmbc 1.0.6 (no NEWS included).
- Drop pysmbc-bnc433994-crash.patch: fixed upstream.
- Really drop system-config-printer-prefill-name-descr.patch.
- Minor cleanup of the file list.
- Use system-config-printer-policykit.patch from my git tree.
- Add cups-pk-helper-bnc468389-dbus-send-dest.patch and
  system-config-printer-bnc468379-dbus-send-dest.patch to add
  send_destination in the dbus policies. Fix bnc#468379 and
  bnc#468387.
* Sun Jan 11 2009 mboman@suse.de
- Fix a small issue in system-config-printer-policykit.patch
* Mon Jan  5 2009 mboman@suse.de
- Update to version 1.1.1:
  + Too many fixes/changes. Please see Changelog for full details.
- Remove system-config-printer-git1.0.x.patch and
  system-config-printer-git1.0.x-po.patch due to version upgrade
- Remove system-config-printer-remove-redhat-base.patch. Fixed upstream
- Remove system-config-printer-prefill-name-descr.patch. Fixed upstream
- Remove pycups package, already in the distro as python-cups
- Respin system-config-printer-install-python.patch
- Respin system-config-printer-policykit.patch
* Tue Dec 16 2008 coolo@suse.de
- require lang subpackage
* Fri Nov 21 2008 vuntz@novell.com
- Update cups-pk-helper to 0.0.3 (there is no upstream project, but
  I still version the code):
  + make various checks to be sure that the arguments passed over
    dbus are valid.
  + fix a major issue with many options never being changed
  + implement various dbus methods that were missing until there,
    so that the old authentication dialog never appears.
  + add more fine-grained PolicyKit policies.
  This is actually needed for bnc#439286.
- Update system-config-printer-policykit.patch to match the
  cups-pk-helper update.
- Drop cups-pk-helper-acceptjobs.patch (fixed in 0.0.3).
- Add system-config-printer-more-checks.patch, to avoid a few
  uncaught exceptions.
* Tue Oct 28 2008 vuntz@novell.com
- Add system-config-printer-prefill-name-descr.patch to prefill
  name and description of new printers. Fix bnc#433633.
* Mon Oct 27 2008 vuntz@novell.com
- Add cups-pk-helper-acceptjobs.patch to make cups-pk-helper
  correctly handle AcceptJobs requests. This is essential to have
  new printers configured with system-config-printer working.
  Fix bnc#433634.
- Add system-config-printer-hide-my-default-printer.patch to hide
  my-default-printer from the menus. Note that
  system-config-printer already provides this functionality.
- Update system-config-printer-policykit.patch so that we don't
  show the old password prompt after changing something in a
  printer.
- Obsoletes gnome-cups-manager. No Provides, since it's not the
  same application...
* Thu Oct 23 2008 vuntz@novell.com
- Add system-config-printer-cups-autoconfig-notifications.patch.
  We display notifications for printers automatically configured
  by cups-autoconfig. This is the missing piece for dropping
  gnome-volume-manager.
* Fri Oct 17 2008 vuntz@novell.com
- Update to version 1.0.8:
  + Handle IPP_FORBIDDEN.
  + Use modelName from custom PPD to suggest name for new printer.
  + Avoid display problem with installable options.
  + Better matching for Lexmark printers.
  + Catch exceptions from advanced server settings dialog.
  + Added some missing OpenPrinting query fields.
  + Jockey support added.
  + Updated translations.
  (summary of changes taken from the Fedora package)
- Remove system-config-printer-forbidden.patch: fixed upstream.
- Add pysmbc-bnc433994-crash.patch to potentially fix a crash when
  browsing smb printers. Should fix bnc#433994.
- Add system-config-printer-git1.0.x.patch to include fixes from
  the 1.0.x branch. This fixes some crashes, and some SMB
  authentication issues. Should fix bnc#433992.
- Add system-config-printer-git1.0.x-po.patch to include updated
  translations from the 1.0.x branch.
- Update system-config-printer-icon-brp-friendly.patch.
* Thu Oct 16 2008 vuntz@novell.com
- Add more categories to my-default-printer.desktop and
  system-config-printer.desktop so that they appear in the control
  center. Fix bnc#433605.
* Fri Oct  3 2008 vuntz@novell.com
- Use %%{py_sitedir} instead of %%{_libdir}/python*/site-packages
* Fri Sep 26 2008 vuntz@novell.com
- Implement fate#4161 and fate#4162:
  + add cups-pk-helper, which is a PolicyKit helper implementing
    some parts of the API exposed by pycups.
  + add system-config-printer-policykit.patch that adds a "backend"
    for system-config-printer to use cups-pk-helper to do the CUPS
    calls.
- It's been discussed a bit with upstream, but no agreement was
  reached on this so far. The patch is not intrusive, so it's the
  best solution right now. I'll try to push it again upstream.
* Wed Sep 17 2008 vuntz@suse.de
- Copy the printer icon from gnome-icon-theme and use it as
  system-config-printer in all desktop files. Add
  system-config-printer-icon-brp-friendly.patch for this.
- Clean up packaging, and use fdupes.
* Wed Sep 10 2008 vuntz@suse.de
- Push to Factory.
* Fri Sep  5 2008 vuntz@novell.com
- Add missing system-config-printer-forbidden.patch.
- Add system-config-printer-install-python.patch to install python
  files where they should live. Also fixes the issue where the
  programs couldn't be run (because they were not +x).
* Fri Sep  5 2008 vuntz@novell.com
- Update to version 1.0.7.
  + See ChangeLog for details.
- Update pycups to 1.9.42 and pysmbc to 1.0.5.
- Remove pysmbc-debug.patch (fixed upstream) and take
  system-config-printer-forbidden.patch from Fedora package.
* Wed Aug 27 2008 vuntz@novell.com
- Update to version 1.0.6.
  + See ChangeLog for details.
* Wed Jul 30 2008 vuntz@novell.com
- Import package, based on the one from fedora and one the one on
  from home:chrismrivera in the build service.
